//=============================================================================
//
//  ABC Export Plugin
//  Based on ABC Import distributed with MuseScore
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License version 2.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//=============================================================================
import QtQuick 2.2
import QtQuick.Controls 1.1
import QtQuick.Dialogs 1.2
import QtQuick.Layouts 1.1
import QtQuick.Window 2.2
import Qt.labs.folderlistmodel 2.1
import Qt.labs.settings 1.0

import MuseScore 3.0
import FileIO 3.0

MuseScore {
    menuPath: "Plugins.ABC Export (jt)"
    version: "1.0.0"
    description: qsTr("This plugin exports the current score to an ABC file. Internet connection is required.")
    requiresScore: true
    pluginType: "dialog"

    id: pluginDialog
    width:  360
    height: 80

    onRun: {
        directorySelectDialog.folder = ((Qt.platform.os == "windows")? "file:///" : "file://") + exportDirectory.text;
    }

    Component.onDestruction: {
        settings.exportDirectory = exportDirectory.text
    }

    Settings {
        id: settings
        category: "Plugin-ABCexport"
        property alias exportDirectory: exportDirectory.text
    }

    FileDialog {
        id: directorySelectDialog
        title: qsTranslate("MS::PathListDialog", "Choose a directory")
        selectFolder: true
        visible: false
        onAccepted: {
            exportDirectory.text = this.folder.toString().replace("file://", "").replace(/^\/(.:\/)(.*)$/, "$1$2");
        }
        Component.onCompleted: visible = false
    }
    
    FileIO {
        id: tempXMLFile
        onError: console.log(msg)
    }

    FileIO {
        id: exportedABCFile
        onError: console.log(msg)
    }

    GridLayout {
        columns: 2
        anchors.fill: parent
        anchors.margins: 10

        Button {
            id: selectDirectory
            text: qsTranslate("ScoreComparisonTool", "Browse")
            onClicked: {
                directorySelectDialog.open();
            }
        }
        Label {
            id: exportDirectory
            text: ""
        }

        Button {
            id: exportButton
            Layout.columnSpan: 2
            text: qsTranslate("ExportDialog", "Export")
            onClicked: {
                exportButton.text = qsTranslate("Ms::MuseScore", "Exporting…");
                
                // Create MusicXML
                tempXMLFile.source = tempXMLFile.tempPath() + "//" + "tempExport.xml";
                writeScore(curScore, tempXMLFile.source, "xml");
                
                // Read it back in and send it out
                var content = "content=" + encodeURIComponent(tempXMLFile.read());
                var request = new XMLHttpRequest();
                request.onreadystatechange = (function() {
                    if (request.readyState == XMLHttpRequest.DONE) {
                        // Save
                        exportedABCFile.source = exportDirectory.text + "//" + curScore.scoreName.replace(/ /g, "_") + ".abc";
                        exportedABCFile.write(request.responseText);
                        // Done
                        exportButton.text = qsTranslate("ExportDialog", "Export");
                        pluginDialog.parent.Window.window.close();
                    }
                });
                request.open("POST", "https://musescore.jeetee.net/abc/xml2abc.py", true);
                request.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
                request.send(content);
            }
        }
    }
}
